# curtislast

A simple django app to demonstarate my understanding of django

Prerequisites
What things you need to install the software atomicwrites==1.3.0 attrs==19.1.0 certifi==2019.6.16 chardet==3.0.4 coverage==4.5.3 Django==2.2.2 entrypoints==0.3 flake8==3.7.7 gunicorn==19.9.0 idna==2.8 importlib-metadata==0.18 mccabe==0.6.1 meld3==1.0.2 more-itertools==7.1.0 packaging==19.0 pluggy==0.12.0 psycopg2==2.8.3 py==1.8.0 pycodestyle==2.5.0 pyflakes==2.1.1 pyparsing==2.4.0 pytest==5.0.0 pytest-cov==2.7.1 pytz==2019.1 requests==2.22.0 setproctitle==1.1.10 six==1.12.0 sqlparse==0.3.0 urllib3==1.25.3 wcwidth==0.1.7 zipp==0.5.1 django-prometheus==1.0.15

Installing
A step by step series of examples that tell you how to get a development env running install a virtual env clone this project to your virtual run docker

Running the tests
run tox run coverage run --source='.' manage.py test coverage report htm

Deployment
Built With
Versioning
1.0.0

Authors
cuttice odhiambo

License
This project is licensed under the MIT License - see the LICENSE.md file for details

